/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2009 Jaroslav Tulach
 */

package cz.xelfi.quoridor.freemarkerdor;

import com.sun.jersey.api.client.WebResource;
import com.sun.jersey.api.client.WebResource.Builder;
import java.net.URI;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Cookie;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

/** Keeps "requests". A request is UUID that maps to a URL which can
 * be executed later.
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
public final class Requests extends Object {
    private final Map<UUID,Builder> requests = new HashMap<UUID, Builder>();
    private final WebResource root;

    Requests(WebResource path) {
        root = path;
    }

    @GET
    @Path("{id}")
    @Produces(MediaType.TEXT_HTML)
    public Response redirect(@PathParam("id") String uuid) {
        UUID r = UUID.fromString(uuid);
        Builder web = requests.get(r);
        if (web == null) {
            return Response.status(Response.Status.NOT_FOUND).build();
        }
        return Response.ok(web.get(String.class)).build();
    }

    boolean isVerified(String uuid) {
        return uuid != null && requests.containsKey(UUID.fromString(uuid));
    }

    URI register(String login, WebResource request) {
        UUID uuid = UUID.randomUUID();
        WebResource callback = root.path(uuid.toString());
        Builder builder = request.queryParam("verified", uuid.toString()).
            cookie(Cookie.valueOf("login=" + login));
        requests.put(uuid, builder);
        return callback.getURI();
    }

}
